Changelog
=========

0.4.0
-----

- Major bugfix: permission to put records in delivery streams

0.3.0
-----

- Major bugfix: give permission to write state to DynamodDB

0.2.0
-----

- Package becomes a generic map-multiplex-map processor (germangh)

0.1.1
-----

- Cleanup package data (bubenkoff)

0.1.0
-----

- Major refactoring to simplify and clean the code (germangh)

0.0.1
-----

- Initial release (bubenkoff)
